<?php
/**
 * InterWorx Hosting Control Panel
 *
 * <pre>
 * +----------------------------------------------------------------------+
 * | Copyright (c) 2000-2021 InterWorx L.L.C., All Rights Reserved.       |
 * +----------------------------------------------------------------------+
 * | Redistribution and use in source form, with or without modification  |
 * | is NOT permitted without consent from the copyright holder.          |
 * |                                                                      |
 * | THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS "AS IS" AND |
 * | ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,    |
 * | THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A          |
 * | PARTICULAR PURPOSE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,    |
 * | EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,  |
 * | PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR   |
 * | PROFITS; OF BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY  |
 * | OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT         |
 * | (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE    |
 * | USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH     |
 * | DAMAGE.                                                              |
 * +----------------------------------------------------------------------+
 * </pre>
 *
 * @package    InterWorx
 * @author     Malin Lorch <mlorch@liquidweb.com>
 * @date       Aug 12, 2021
 */

/**
 * @package InterWorx
 * @subpackage
 */
class AcronisReply
{
    const REPLY_DATABASES = 'databases';
    const REPLY_DIRECTORIES = 'directories';
    const REPLY_UNIT = 'unit';
    const REPLY_ITEMS = 'items';
    const REPLY_NAME = 'name';
    const REPLY_PATH = 'path';
    const REPLY_SIZE = 'size';
    const REPLY_SUBTOTAL = 'subtotal';
    const REPLY_TOTAL = 'total';
    const REPLY_BYTES = 'B';
    const REPLY_MESSAGE = 'message';

    const LANG_ERROR_UNSPECIFIED = '##LG_UNKNOWN_ERROR##';
    const LANG_ERROR_RESUME_RECOVERY = '##LG_ACRONIS_RESUME_RECOVERY_ERROR##';
    const LANG_API_FAILURE = '##LG_ACRONIS_API_FAILURE##';
    const LANG_NOT_AUTHORIZED = '##LG_ACRONIS_NOT_AUTHORIZED##';
    const LANG_INTERNAL_ERROR = '##LG_ACRONIS_INTERNAL_ERROR##';
    const LANG_PRE_SW_ACCOUNT = '##LG_ACRONIS_NO_BACKUP##';
    const LANG_AGENT_INSTALL_ERROR = '##LG_ACRONIS_INSTALLATION_ERROR##';
    const LANG_AGENT_UNINSTALL_ERROR = '##LG_ACRONIS_UNINSTALL_ERROR##';
    const LANG_DB_DOES_NOT_EXIST = '##LG_ACRONIS_NO_DB##';
    const LANG_DB_RECOVERY_ALREADY_IN_PROGRESS = '##LG_AB_DB_RECOVERY_ALREADY_IN_PROGRESS##';
    const LANG_RECOVERY_ALREADY_IN_PROGRESS = '##LG_ACRONIS_ERROR_RESTORE_IN_PROGRESS##';
    const LANG_DB_NOT_ENABLED = '##LG_DB_RECOVERY_NOT_ENABLED##';
    const LANG_INVALID_INPUT = '##LG_ACRONIS_INVALID_INPUT##';
    const LANG_INVALID_PATH = '##LG_ACRONIS_INVALID_PATH##';
    const LANG_BACKUPPLAN_ALREADY_ACTIVATED = '##LG_ACRONIS_ALREADY_ACTIVE##';
    const LANG_NO_PLAN_ASSIGNED = '##LG_ACRONIS_NO_PLAN_ASSIGNED##';

    const LANG_INSTALL_SUCCESS = '##LG_ACRONIS_INSTALL_SUCCESS##';
    const LANG_UNINTALL_SUCCESS = '##LG_ACRONIS_UNINSTALL_SUCCESS##';
    const LANG_IN_PROGRESS = '##LG_RECOVERY_IN_PROGRESS##';
    const LANG_IN_PROGRESS_ALT_LOCATION = '##LG_RECOVERY_IN_PROGRESS_LOCATION##';

    const ERROR_UNSPECIFIED = Reply::ERROR_PLUGIN;
    const ERROR_INTERNAL = Reply::ERROR_YOURE_DOING_IT_WRONG;
    const ERROR_INVALID_INPUT = Reply::ERROR_CLIENT_INPUT;

    const ERROR_API = 899;
    const ERROR_API_NOT_RESPONSIVE = 898;
    const ERROR_API_INVALID_CREDENTIALS = 897;
    const ERROR_API_INVALID_COOKIE = 896;
    const ERROR_API_INVALID_USER_TYPE = 895;
    const ERROR_API_BAD_GATEWAY = 894;
    const ERROR_API_INVALID_ENDPOINT = 893;

    const ERROR_CACHE = 889;
    const ERROR_CACHE_PRE_PRESCRIPT = 888;
    const ERROR_CACHE_PRE_DB_SIZE = 887;
    const ERROR_CACHE_PRESCRIPT_NO_BACKUP = 886;

    const ERROR_SW_ACCOUNT_DOES_NOT_EXIST = 879;
    const ERROR_DB_DOES_NOT_EXIST = 878;
    const ERROR_DB_RECOVERY_NOT_ENABLED = 877;
    const ERROR_INVALID_PATH = 876;

    const ERROR_BACKUPAGENT_INSTALL_FAILURE = 869;
    const ERROR_BACKUPAGENT_UNINSTALL_FAILURE = 868;

    const ERROR_RECOVERY_IN_PROGRESS = 859;
    const ERROR_DB_RECOVERY_IN_PROGRESS = 858;
    const ERROR_RESUME_RECOVERY = 857;

    const ERROR_BACKUPPLAN_ALREADY_ACTIVE = 849;
    const ERROR_BACKUPPLAN_MISSING = 848;
    const ERROR_BACKUPPLAN_NONE_ASSIGNED = 847;

    const ERROR_CURL = 839;
    const ERROR_CURL_INVALID_URL = 838;

    /**
     * @param integer $errorCode
     */
    public static function getErrorLangKey($errorCode)
    {
        $langKey = self::_getErrorLangKey($errorCode);

        if (is_null($langKey)) {
            return self::LANG_ERROR_UNSPECIFIED;
        }

        return $langKey;
    }

    /**
     * @param integer $errorCode
     * @return array
     */
    private static function _getErrorLangKey($errorCode)
    {
        $errorCodes = array(
            self::ERROR_UNSPECIFIED => self::LANG_ERROR_UNSPECIFIED,
            self::ERROR_API => self::LANG_API_FAILURE,
            self::ERROR_API_NOT_RESPONSIVE => self::LANG_API_FAILURE,
            self::ERROR_API_INVALID_CREDENTIALS => self::LANG_NOT_AUTHORIZED,
            self::ERROR_API_INVALID_USER_TYPE => self::LANG_NOT_AUTHORIZED,
            self::ERROR_API_BAD_GATEWAY => self::LANG_API_FAILURE,
            self::ERROR_CACHE => self::LANG_INTERNAL_ERROR,
            self::ERROR_CACHE_PRE_PRESCRIPT => self::LANG_INTERNAL_ERROR,
            self::ERROR_SW_ACCOUNT_DOES_NOT_EXIST => self::LANG_PRE_SW_ACCOUNT,
            self::ERROR_INTERNAL => self::LANG_INTERNAL_ERROR,
            self::ERROR_BACKUPAGENT_INSTALL_FAILURE => self::LANG_AGENT_INSTALL_ERROR,
            self::ERROR_BACKUPAGENT_UNINSTALL_FAILURE => self::LANG_AGENT_UNINSTALL_ERROR,
            self::ERROR_RECOVERY_IN_PROGRESS => self::LANG_RECOVERY_ALREADY_IN_PROGRESS,
            self::ERROR_DB_RECOVERY_IN_PROGRESS => self::LANG_DB_RECOVERY_ALREADY_IN_PROGRESS,
            self::ERROR_DB_RECOVERY_NOT_ENABLED => self::LANG_DB_NOT_ENABLED,
            self::ERROR_INVALID_INPUT => self::LANG_INVALID_INPUT,
            self::ERROR_INVALID_PATH => self::LANG_INVALID_PATH,
            self::ERROR_RESUME_RECOVERY => self::LANG_ERROR_RESUME_RECOVERY,
            self::ERROR_BACKUPPLAN_ALREADY_ACTIVE => self::LANG_INTERNAL_ERROR,
            self::ERROR_BACKUPPLAN_MISSING => self::LANG_INTERNAL_ERROR,
            self::ERROR_BACKUPPLAN_NONE_ASSIGNED => self::LANG_NO_PLAN_ASSIGNED,
            self::ERROR_CACHE_PRESCRIPT_NO_BACKUP => self::LANG_INTERNAL_ERROR,
            self::ERROR_DB_DOES_NOT_EXIST => self::LANG_DB_DOES_NOT_EXIST,
            self::ERROR_API_INVALID_ENDPOINT => self::LANG_NOT_AUTHORIZED,
            self::ERROR_CURL => self::LANG_INTERNAL_ERROR,
            self::ERROR_CURL_INVALID_URL => self::LANG_NOT_AUTHORIZED
        );

        return $errorCodes[$errorCode];
    }
}
